@@ -444,7 +444,7 @@ protected:
 
   /** Destroys this OpenCL context object. If the underlying
    * GetContextId() has been created, then it will be released. */
-  virtual ~OpenCLContext();
+  ~OpenCLContext() override;
 
   /** \internal
    * This method is only used when CMake OpenCL profiling is enabled. */
@@ -469,7 +469,7 @@ private:
 
   ITK_OPENCL_DECLARE_PRIVATE( OpenCLContext )
 
-  std::auto_ptr< OpenCLContextPimpl > d_ptr;
+  std::unique_ptr< OpenCLContextPimpl > d_ptr;
   static Pointer m_Instance;
 
   /** Quick get active queue method for friend classes. */
