@@ -145,7 +145,7 @@ public:
   itkStaticConstMacro( ImageDimension, unsigned int, FixedImageType::ImageDimension );
 
   /** Initialize the penalty term. */
-  virtual void Initialize( void ) throw ( ExceptionObject );
+  void Initialize( void ) override;
 
   /** Typedef's for B-spline transform. */
   typedef BSplineOrder3TransformType                 BSplineTransformType;
@@ -186,23 +186,23 @@ public:
   void CheckUseAndCalculationBooleans( void );
 
   /** The GetValue()-method returns the rigid penalty value. */
-  virtual MeasureType GetValue(
-    const ParametersType & parameters ) const;
+  MeasureType GetValue(
+    const ParametersType & parameters ) const override;
 
   /** The GetDerivative()-method returns the rigid penalty derivative. */
-  virtual void GetDerivative(
+  void GetDerivative(
     const ParametersType & parameters,
-    DerivativeType & derivative ) const;
+    DerivativeType & derivative ) const override;
 
   /** Contains calls from GetValueAndDerivative that are thread-unsafe. */
-  virtual void BeforeThreadedGetValueAndDerivative(
-    const TransformParametersType & parameters ) const;
+  void BeforeThreadedGetValueAndDerivative(
+    const TransformParametersType & parameters ) const override;
 
   /** The GetValueAndDerivative()-method returns the rigid penalty value and its derivative. */
-  virtual void GetValueAndDerivative(
+  void GetValueAndDerivative(
     const ParametersType & parameters,
     MeasureType & value,
-    DerivativeType & derivative ) const;
+    DerivativeType & derivative ) const override;
 
   /** Set the B-spline transform in this class.
    * This class expects a BSplineTransform! It is not suited for others.
@@ -299,10 +299,10 @@ protected:
   /** The constructor. */
   TransformRigidityPenaltyTerm();
   /** The destructor. */
-  virtual ~TransformRigidityPenaltyTerm() {}
+  ~TransformRigidityPenaltyTerm() override {}
 
   /** PrintSelf. */
-  void PrintSelf( std::ostream & os, Indent indent ) const;
+  void PrintSelf( std::ostream & os, Indent indent ) const override;
 
 private:
 
