@@ -20,12 +20,14 @@
 
 #include "elxIncludes.h" // include first to avoid MSVS warning
 #include "itkAdaptiveStochasticGradientDescentOptimizer.h"
-#include "itkComputeJacobianTerms.h"
-#include "itkComputeDisplacementDistribution.h"
+
+#include "itkComputeJacobianTerms.h"            // For  ASGD step size
+#include "itkComputeDisplacementDistribution.h" // For FASGD step size
 #include "elxProgressCommand.h"
 #include "itkAdvancedTransform.h"
 #include "itkMersenneTwisterRandomVariateGenerator.h"
 
+
 namespace elastix
 {
 /**
@@ -58,10 +60,10 @@ namespace elastix
  *
  * Acceleration in case of many transform parameters was proposed in the following paper:
  *
- * [3]  Y.Qiao, B.P.F. Lelieveldt, M.Staring
- * "Fast automatic estimation of the optimization step size for nonrigid image registration,"
- * SPIE Medical Imaging: Image Processing,February, 2014.
- * http://elastix.isi.uu.nl/marius/publications/2014_c_SPIEMI.php
+ * [3] Y. Qiao, B. van Lew, B.P.F. Lelieveldt and M. Staring
+ * "Fast Automatic Step Size Estimation for Gradient Descent Optimization of Image Registration,"
+ * IEEE Transactions on Medical Imaging, vol. 35, no. 2, pp. 391 - 403, February 2016.
+ * http://elastix.isi.uu.nl/marius/publications/2016_j_TMIa.php
  *
  * The parameters used in this class are:
  * \parameter Optimizer: Select this optimizer as follows:\n
@@ -235,29 +237,29 @@ public:
   /** Methods invoked by elastix, in which parameters can be set and
    * progress information can be printed.
    */
-  virtual void BeforeRegistration( void );
+  void BeforeRegistration( void ) override;
 
-  virtual void BeforeEachResolution( void );
+  void BeforeEachResolution( void ) override;
 
-  virtual void AfterEachResolution( void );
+  void AfterEachResolution( void ) override;
 
-  virtual void AfterEachIteration( void );
+  void AfterEachIteration( void ) override;
 
-  virtual void AfterRegistration( void );
+  void AfterRegistration( void ) override;
 
   /** Check if any scales are set, and set the UseScales flag on or off;
    * after that call the superclass' implementation.
    */
-  virtual void StartOptimization( void );
+  void StartOptimization( void ) override;
 
   /** If automatic gain estimation is desired, then estimate SP_a, SP_alpha
    * SigmoidScale, SigmoidMax, SigmoidMin.
    * After that call Superclass' implementation.
    */
-  virtual void ResumeOptimization( void );
+  void ResumeOptimization( void ) override;
 
   /** Stop optimization and pass on exception. */
-  virtual void MetricErrorResponse( itk::ExceptionObject & err );
+  void MetricErrorResponse( itk::ExceptionObject & err ) override;
 
   /** Set/Get whether automatic parameter estimation is desired.
    * If true, make sure to set the maximum step length.
@@ -284,8 +286,8 @@ public:
 protected:
 
   /** Protected typedefs */
-  typedef typename RegistrationType::FixedImageType  FixedImageType;
-  typedef typename RegistrationType::MovingImageType MovingImageType;
+  typedef typename RegistrationType::FixedImageType   FixedImageType;
+  typedef typename RegistrationType::MovingImageType  MovingImageType;
 
   typedef typename FixedImageType::RegionType         FixedImageRegionType;
   typedef typename FixedImageType::IndexType          FixedImageIndexType;
@@ -338,7 +340,7 @@ protected:
     AdvancedTransformType::NonZeroJacobianIndicesType NonZeroJacobianIndicesType;
 
   AdaptiveStochasticGradientDescent();
-  virtual ~AdaptiveStochasticGradientDescent() {}
+  ~AdaptiveStochasticGradientDescent() override {}
 
   /** Variable to store the automatically determined settings for each resolution. */
   SettingsVectorType m_SettingsVector;
@@ -407,6 +409,7 @@ private:
 
   bool   m_AutomaticParameterEstimation;
   double m_MaximumStepLength;
+  double m_MaximumStepLengthRatio;
 
   /** Private variables for the sampling attempts. */
   SizeValueType m_MaximumNumberOfSamplingAttempts;
