@@ -27,9 +27,10 @@
 #include "elxElastixMain.h"
 
 #include "elxMacro.h"
-#include "itkMultiThreader.h"
+#include "itkPlatformMultiThreader.h"
 
 #ifdef ELASTIX_USE_OPENCL
+#include "itkOpenCLContext.h"
 #include "itkOpenCLSetup.h"
 #endif
 
@@ -161,8 +162,9 @@ ElastixMain::ElastixMain()
  * ****************** Initialization of static members *********
  */
 
-ElastixMain::ComponentDatabasePointer ElastixMain::s_CDB             = 0;
-ElastixMain::ComponentLoaderPointer   ElastixMain::s_ComponentLoader = 0;
+// Both s_CDB and s_ComponentLoader are defaulted-constructed to null.
+ElastixMain::ComponentDatabasePointer ElastixMain::s_CDB;
+ElastixMain::ComponentLoaderPointer   ElastixMain::s_ComponentLoader;
 
 /**
  * ********************** Destructor ****************************
@@ -186,7 +188,7 @@ ElastixMain::~ElastixMain()
 
 void
 ElastixMain
-::EnterCommandLineArguments( ArgumentMapType & argmap )
+::EnterCommandLineArguments( const ArgumentMapType & argmap )
 {
 
   /** Initialize the configuration object with the
@@ -208,8 +210,8 @@ ElastixMain
 
 void
 ElastixMain
-::EnterCommandLineArguments( ArgumentMapType & argmap,
-  ParameterMapType & inputMap )
+::EnterCommandLineArguments( const ArgumentMapType & argmap,
+  const ParameterMapType & inputMap )
 {
   /** Initialize the configuration object with the
    * command line parameters entered by the user.
@@ -229,8 +231,8 @@ ElastixMain
 
 void
 ElastixMain
-::EnterCommandLineArguments( ArgumentMapType & argmap,
-  std::vector< ParameterMapType > & inputMaps )
+::EnterCommandLineArguments( const ArgumentMapType & argmap,
+  const std::vector< ParameterMapType > & inputMaps )
 {
   this->m_Configurations.clear();
   this->m_Configurations.resize( inputMaps.size() );
@@ -373,14 +375,14 @@ ElastixMain::Run( void )
   /** Set the images and masks. If not set by the user, it is not a problem.
    * ElastixTemplate will try to load them from disk.
    */
-  this->GetElastixBase()->SetFixedImageContainer( this->GetFixedImageContainer() );
-  this->GetElastixBase()->SetMovingImageContainer( this->GetMovingImageContainer() );
-  this->GetElastixBase()->SetFixedMaskContainer( this->GetFixedMaskContainer() );
-  this->GetElastixBase()->SetMovingMaskContainer( this->GetMovingMaskContainer() );
-  this->GetElastixBase()->SetResultImageContainer( this->GetResultImageContainer() );
+  this->GetElastixBase()->SetFixedImageContainer( this->GetModifiableFixedImageContainer() );
+  this->GetElastixBase()->SetMovingImageContainer( this->GetModifiableMovingImageContainer() );
+  this->GetElastixBase()->SetFixedMaskContainer( this->GetModifiableFixedMaskContainer() );
+  this->GetElastixBase()->SetMovingMaskContainer( this->GetModifiableMovingMaskContainer() );
+  this->GetElastixBase()->SetResultImageContainer( this->GetModifiableResultImageContainer() );
 
   /** Set the initial transform, if it happens to be there. */
-  this->GetElastixBase()->SetInitialTransform( this->GetInitialTransform() );
+  this->GetElastixBase()->SetInitialTransform( this->GetModifiableInitialTransform() );
 
   /** Set the original fixed image direction cosines (relevant in case the
    * UseDirectionCosines parameter was set to false.
@@ -442,7 +444,7 @@ ElastixMain::Run( void )
  */
 
 int
-ElastixMain::Run( ArgumentMapType & argmap )
+ElastixMain::Run( const ArgumentMapType & argmap )
 {
   this->EnterCommandLineArguments( argmap );
   return this->Run();
@@ -455,8 +457,8 @@ ElastixMain::Run( ArgumentMapType & argmap )
 
 int
 ElastixMain
-::Run( ArgumentMapType & argmap,
-  ParameterMapType & inputMap )
+::Run( const ArgumentMapType & argmap,
+  const ParameterMapType & inputMap )
 {
   this->EnterCommandLineArguments( argmap, inputMap );
   return this->Run();
@@ -489,62 +491,65 @@ ElastixMain::InitDBIndex( void )
     /** FixedImageDimension. */
     if( this->m_FixedImageDimension == 0 )
     {
-#ifndef _ELASTIX_BUILD_LIBRARY
-      /** Get the fixed image file name. */
-      std::string fixedImageFileName
-        = this->m_Configuration->GetCommandLineArgument( "-f" );
-      if( fixedImageFileName == "" )
+      if (!BaseComponent::IsElastixLibrary())
       {
-        fixedImageFileName = this->m_Configuration->GetCommandLineArgument( "-f0" );
-      }
-
-      /** Sanity check. */
-      if( fixedImageFileName == "" )
-      {
-        xout[ "error" ] << "ERROR: could not read fixed image." << std::endl;
-        xout[ "error" ] << "  both -f and -f0 are unspecified" << std::endl;
-        return 1;
-      }
-
-      /** Read it from the fixed image header. */
-      try
-      {
-        this->GetImageInformationFromFile( fixedImageFileName,
-          this->m_FixedImageDimension );
-      }
-      catch( itk::ExceptionObject & err )
-      {
-        xout[ "error" ] << "ERROR: could not read fixed image." << std::endl;
-        xout[ "error" ] << err << std::endl;
-        return 1;
-      }
-
-      /** Try to read it from the parameter file.
-       * This only serves as a check; elastix versions prior to 4.6 read the dimension
-       * from the parameter file, but now we read it from the image header.
-       */
-      unsigned int fixDimParameterFile  = 0;
-      bool         foundInParameterFile = this->m_Configuration->ReadParameter( fixDimParameterFile,
-        "FixedImageDimension", 0, false );
-
-      /** Check. */
-      if( foundInParameterFile )
-      {
-        if( fixDimParameterFile != this->m_FixedImageDimension )
+        /** Get the fixed image file name. */
+        std::string fixedImageFileName
+          = this->m_Configuration->GetCommandLineArgument( "-f" );
+        if( fixedImageFileName == "" )
         {
-          xout[ "error" ] << "ERROR: problem defining fixed image dimension.\n"
-                          << "  The parameter file says:     " << fixDimParameterFile << "\n"
-                          << "  The fixed image header says: " << this->m_FixedImageDimension << "\n"
-                          << "  Note that from elastix 4.6 the parameter file definition \"FixedImageDimension\" "
-                          << "is not needed anymore.\n  Please remove this entry from your parameter file."
-                          << std::endl;
+          fixedImageFileName = this->m_Configuration->GetCommandLineArgument( "-f0" );
+        }
+
+        /** Sanity check. */
+        if( fixedImageFileName == "" )
+        {
+          xout[ "error" ] << "ERROR: could not read fixed image." << std::endl;
+          xout[ "error" ] << "  both -f and -f0 are unspecified" << std::endl;
           return 1;
         }
+
+        /** Read it from the fixed image header. */
+        try
+        {
+          this->GetImageInformationFromFile( fixedImageFileName,
+            this->m_FixedImageDimension );
+        }
+        catch( itk::ExceptionObject & err )
+        {
+          xout[ "error" ] << "ERROR: could not read fixed image." << std::endl;
+          xout[ "error" ] << err << std::endl;
+          return 1;
+        }
+
+        /** Try to read it from the parameter file.
+         * This only serves as a check; elastix versions prior to 4.6 read the dimension
+         * from the parameter file, but now we read it from the image header.
+         */
+        unsigned int fixDimParameterFile  = 0;
+        bool         foundInParameterFile = this->m_Configuration->ReadParameter( fixDimParameterFile,
+          "FixedImageDimension", 0, false );
+
+        /** Check. */
+        if( foundInParameterFile )
+        {
+          if( fixDimParameterFile != this->m_FixedImageDimension )
+          {
+            xout[ "error" ] << "ERROR: problem defining fixed image dimension.\n"
+                            << "  The parameter file says:     " << fixDimParameterFile << "\n"
+                            << "  The fixed image header says: " << this->m_FixedImageDimension << "\n"
+                            << "  Note that from elastix 4.6 the parameter file definition \"FixedImageDimension\" "
+                            << "is not needed anymore.\n  Please remove this entry from your parameter file."
+                            << std::endl;
+            return 1;
+          }
+        }
+      }
+      else
+      {
+        this->m_Configuration->ReadParameter( this->m_FixedImageDimension,
+          "FixedImageDimension", 0, false );
       }
-#else
-      this->m_Configuration->ReadParameter( this->m_FixedImageDimension,
-        "FixedImageDimension", 0, false );
-#endif
 
       /** Just a sanity check, probably not needed. */
       if( this->m_FixedImageDimension == 0 )
@@ -567,63 +572,65 @@ ElastixMain::InitDBIndex( void )
     /** MovingImageDimension. */
     if( this->m_MovingImageDimension == 0 )
     {
-#ifndef _ELASTIX_BUILD_LIBRARY
-      /** Get the moving image file name. */
-      std::string movingImageFileName
-        = this->m_Configuration->GetCommandLineArgument( "-m" );
-      if( movingImageFileName == "" )
+      if (!BaseComponent::IsElastixLibrary())
       {
-        movingImageFileName = this->m_Configuration->GetCommandLineArgument( "-m0" );
-      }
-
-      /** Sanity check. */
-      if( movingImageFileName == "" )
-      {
-        xout[ "error" ] << "ERROR: could not read moving image." << std::endl;
-        xout[ "error" ] << "  both -m and -m0 are unspecified" << std::endl;
-        return 1;
-      }
-
-      /** Read it from the moving image header. */
-      try
-      {
-        this->GetImageInformationFromFile( movingImageFileName,
-          this->m_MovingImageDimension );
-      }
-      catch( itk::ExceptionObject & err )
-      {
-        xout[ "error" ] << "ERROR: could not read moving image." << std::endl;
-        xout[ "error" ] << err << std::endl;
-        return 1;
-      }
-
-      /** Try to read it from the parameter file.
-       * This only serves as a check; elastix versions prior to 4.6 read the dimension
-       * from the parameter file, but now we read it from the image header.
-       */
-      unsigned int movDimParameterFile  = 0;
-      bool         foundInParameterFile = this->m_Configuration->ReadParameter( movDimParameterFile,
-        "MovingImageDimension", 0, false );
-
-      /** Check. */
-      if( foundInParameterFile )
-      {
-        if( movDimParameterFile != this->m_MovingImageDimension )
+        /** Get the moving image file name. */
+        std::string movingImageFileName
+          = this->m_Configuration->GetCommandLineArgument( "-m" );
+        if( movingImageFileName == "" )
         {
-          xout[ "error" ] << "ERROR: problem defining moving image dimension.\n"
-                          << "  The parameter file says:      " << movDimParameterFile << "\n"
-                          << "  The moving image header says: " << this->m_MovingImageDimension << "\n"
-                          << "  Note that from elastix 4.6 the parameter file definition \"MovingImageDimension\" "
-                          << "is not needed anymore.\n  Please remove this entry from your parameter file."
-                          << std::endl;
+          movingImageFileName = this->m_Configuration->GetCommandLineArgument( "-m0" );
+        }
+
+        /** Sanity check. */
+        if( movingImageFileName == "" )
+        {
+          xout[ "error" ] << "ERROR: could not read moving image." << std::endl;
+          xout[ "error" ] << "  both -m and -m0 are unspecified" << std::endl;
           return 1;
         }
-      }
 
-#else
-      this->m_Configuration->ReadParameter( this->m_MovingImageDimension,
-        "MovingImageDimension", 0, false );
-#endif
+        /** Read it from the moving image header. */
+        try
+        {
+          this->GetImageInformationFromFile( movingImageFileName,
+            this->m_MovingImageDimension );
+        }
+        catch( itk::ExceptionObject & err )
+        {
+          xout[ "error" ] << "ERROR: could not read moving image." << std::endl;
+          xout[ "error" ] << err << std::endl;
+          return 1;
+        }
+
+        /** Try to read it from the parameter file.
+         * This only serves as a check; elastix versions prior to 4.6 read the dimension
+         * from the parameter file, but now we read it from the image header.
+         */
+        unsigned int movDimParameterFile  = 0;
+        bool         foundInParameterFile = this->m_Configuration->ReadParameter( movDimParameterFile,
+          "MovingImageDimension", 0, false );
+
+        /** Check. */
+        if( foundInParameterFile )
+        {
+          if( movDimParameterFile != this->m_MovingImageDimension )
+          {
+            xout[ "error" ] << "ERROR: problem defining moving image dimension.\n"
+                            << "  The parameter file says:      " << movDimParameterFile << "\n"
+                            << "  The moving image header says: " << this->m_MovingImageDimension << "\n"
+                            << "  Note that from elastix 4.6 the parameter file definition \"MovingImageDimension\" "
+                            << "is not needed anymore.\n  Please remove this entry from your parameter file."
+                            << std::endl;
+            return 1;
+          }
+        }
+      }
+      else
+      {
+        this->m_Configuration->ReadParameter( this->m_MovingImageDimension,
+          "MovingImageDimension", 0, false );
+      }
 
       /** Just a sanity check, probably not needed. */
       if( this->m_MovingImageDimension == 0 )
@@ -811,9 +818,11 @@ ElastixMain::CreateComponent(
 {
   /** A pointer to the New() function. */
   PtrToCreator  testcreator = 0;
-  ObjectPointer testpointer = 0;
   testcreator = this->s_CDB->GetCreator( name,  this->m_DBIndex );
-  testpointer = testcreator ? testcreator() : NULL;
+
+  // Note that ObjectPointer() yields a default-constructed SmartPointer (null).
+  ObjectPointer testpointer = testcreator ? testcreator() : ObjectPointer();
+
   if( testpointer.IsNull() )
   {
     itkExceptionMacro( << "The following component could not be created: " << name );
@@ -909,7 +918,7 @@ ElastixMain::CreateComponents(
         return objectContainer;
       }
     } // end if
-  }   // end while
+  } // end while
 
   return objectContainer;
 
@@ -980,7 +989,7 @@ ElastixMain::SetMaximumNumberOfThreads( void ) const
   {
     const int maximumNumberOfThreads
       = atoi( maximumNumberOfThreadsString.c_str() );
-    itk::MultiThreader::SetGlobalMaximumNumberOfThreads(
+    itk::MultiThreaderBase::SetGlobalMaximumNumberOfThreads(
       maximumNumberOfThreads );
   }
 } // end SetMaximumNumberOfThreads()
@@ -1045,7 +1054,7 @@ ElastixMain::GetImageInformationFromFile(
     testReader->UpdateOutputInformation();
 
     /** Extract the required information. */
-    itk::ImageIOBase::Pointer testImageIO = testReader->GetImageIO();
+    itk::SmartPointer<const itk::ImageIOBase> testImageIO = testReader->GetImageIO();
     //itk::ImageIOBase::IOComponentType componentType = testImageIO->GetComponentType();
     //pixelType = itk::ImageIOBase::GetComponentTypeAsString( componentType );
     if( testImageIO.IsNull() )
